==> deepin-polkit-agent-5.4.16-1.src.tar.gz: dde-polkit-agent-5.4.16/translations/dde-polkit-agent_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../AuthDialog.cpp" line="96"/>
        <source>Finger moved too fast, please do not lift until prompted</source>
        <translation>Gishti lëvizi shumë shpejt, ju lutemi, mos e ngrini para se t’ju kërkohet</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="98"/>
        <source>Verification failed, two chances left</source>
        <translation>Verifikimi dështoi, edhe dy prova.</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="118"/>
        <location filename="../AuthDialog.cpp" line="303"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="213"/>
        <source>You are required to change your password immediately (password expired)</source>
        <translation>Është e domosdoshme të ndryshoni fjalëkalimin tuaj  menjëherë (fjalëkalimi ka skaduar)</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="278"/>
        <source>Wrong password, only one chance left</source>
        <translation>Fjalëkalim i gabuar, edhe një provë</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="281"/>
        <source>Wrong password, two chances left</source>
        <translation>Fjalëkalim i gabuar, edhe dy prova</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="285"/>
        <source>Wrong password</source>
        <translation>Fjalëkalim i gabuar</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="302"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
</context>
</TS>

==> deepin-polkit-agent-5.4.17-1.src.tar.gz: dde-polkit-agent-5.4.17/translations/dde-polkit-agent_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../AuthDialog.cpp" line="98"/>
        <source>Finger moved too fast, please do not lift until prompted</source>
        <translation>Gishti lëvizi shumë shpejt, ju lutemi, mos e ngrini para se t’ju kërkohet</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="100"/>
        <source>Verification failed, two chances left</source>
        <translation>Verifikimi dështoi, edhe dy prova.</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="120"/>
        <location filename="../AuthDialog.cpp" line="326"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="227"/>
        <source>You are required to change your password immediately (password expired)</source>
        <translation>Është e domosdoshme të ndryshoni fjalëkalimin tuaj  menjëherë (fjalëkalimi ka skaduar)</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="299"/>
        <source>Locked, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong password, only one chance left</source>
        <translation type="vanished">Fjalëkalim i gabuar, edhe një provë</translation>
    </message>
    <message>
        <source>Wrong password, two chances left</source>
        <translation type="vanished">Fjalëkalim i gabuar, edhe dy prova</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="301"/>
        <source>Wrong password</source>
        <translation>Fjalëkalim i gabuar</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="325"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
</context>
</TS>
